@@ -1,5 +1,3 @@
-from autolens.aggregator.aggregator import dataset_generator_from_aggregator as Dataset
-from autolens.aggregator.aggregator import mask_generator_from_aggregator as Mask
 from autolens.aggregator.aggregator import (
     masked_imaging_generator_from_aggregator as MaskedImaging,
 )
@@ -7,8 +5,6 @@ from autolens.aggregator.aggregator import tracer_generator_from_aggregator as T
 from autolens.aggregator.aggregator import (
     fit_imaging_generator_from_aggregator as FitImaging,
 )
-from autolens.aggregator.aggregator import dataset_from_agg_obj
-from autolens.aggregator.aggregator import mask_from_agg_obj
 from autolens.aggregator.aggregator import masked_imaging_from_agg_obj
 from autolens.aggregator.aggregator import tracer_from_agg_obj
 from autolens.aggregator.aggregator import fit_imaging_from_agg_obj
