@@ -1,39 +1,6 @@
 import autolens as al
 
 
-def dataset_generator_from_aggregator(aggregator):
-    return aggregator.map(func=dataset_from_agg_obj)
-
-
-def dataset_from_agg_obj(agg_obj):
-    return agg_obj.dataset
-
-
-def mask_generator_from_aggregator(aggregator):
-    return aggregator.map(func=mask_from_agg_obj)
-
-
-def mask_from_agg_obj(agg_obj):
-    return agg_obj.mask
-
-
-def masked_imaging_generator_from_aggregator(aggregator):
-    return aggregator.map(func=masked_imaging_from_agg_obj)
-
-
-def masked_imaging_from_agg_obj(agg_obj):
-
-    return al.MaskedImaging(
-        imaging=agg_obj.dataset,
-        mask=agg_obj.mask,
-        psf_shape_2d=agg_obj.meta_dataset.psf_shape_2d,
-        pixel_scale_interpolation_grid=agg_obj.meta_dataset.pixel_scale_interpolation_grid,
-        inversion_pixel_limit=agg_obj.meta_dataset.inversion_pixel_limit,
-        inversion_uses_border=agg_obj.meta_dataset.inversion_uses_border,
-        positions_threshold=agg_obj.meta_dataset.positions_threshold,
-    )
-
-
 def tracer_generator_from_aggregator(aggregator):
     return aggregator.map(func=tracer_from_agg_obj)
 
@@ -59,6 +26,23 @@ def tracer_from_agg_obj(agg_obj):
     return al.Tracer.from_galaxies(galaxies=galaxies)
 
 
+def masked_imaging_generator_from_aggregator(aggregator):
+    return aggregator.map(func=masked_imaging_from_agg_obj)
+
+
+def masked_imaging_from_agg_obj(agg_obj):
+
+    return al.MaskedImaging(
+        imaging=agg_obj.dataset,
+        mask=agg_obj.mask,
+        psf_shape_2d=agg_obj.meta_dataset.psf_shape_2d,
+        pixel_scale_interpolation_grid=agg_obj.meta_dataset.pixel_scale_interpolation_grid,
+        inversion_pixel_limit=agg_obj.meta_dataset.inversion_pixel_limit,
+        inversion_uses_border=agg_obj.meta_dataset.inversion_uses_border,
+        positions_threshold=agg_obj.meta_dataset.positions_threshold,
+    )
+
+
 def fit_imaging_generator_from_aggregator(aggregator):
     return aggregator.map(func=fit_imaging_from_agg_obj)
 
