@@ -117,7 +117,7 @@ class SimulatorImaging(imaging.SimulatorImaging):
             noise_seed=noise_seed,
         )
 
-    def from_tracer_and_grid(self, tracer, grid, name=None, metadata=None):
+    def from_tracer_and_grid(self, tracer, grid, name=None):
         """
         Create a realistic simulated image by applying effects to a plain simulated image.
 
@@ -162,11 +162,9 @@ class SimulatorImaging(imaging.SimulatorImaging):
 
             simulator = self
 
-        return simulator.from_image(
-            image=image.in_1d_binned, name=name, metadata=metadata
-        )
+        return simulator.from_image(image=image.in_1d_binned, name=name)
 
-    def from_galaxies_and_grid(self, galaxies, grid, name=None, metadata=None):
+    def from_galaxies_and_grid(self, galaxies, grid, name=None):
         """Simulate imaging data for this data_type, as follows:
 
         1)  Setup the image-plane grid of the Imaging arrays, which defines the coordinates used for the ray-tracing.
@@ -184,13 +182,9 @@ class SimulatorImaging(imaging.SimulatorImaging):
 
         tracer = ray_tracing.Tracer.from_galaxies(galaxies=galaxies)
 
-        return self.from_tracer_and_grid(
-            tracer=tracer, grid=grid, name=name, metadata=metadata
-        )
+        return self.from_tracer_and_grid(tracer=tracer, grid=grid, name=name)
 
-    def from_deflections_and_galaxies(
-        self, deflections, galaxies, name=None, metadata=None
-    ):
+    def from_deflections_and_galaxies(self, deflections, galaxies, name=None):
 
         grid = grids.Grid.uniform(
             shape_2d=deflections.shape_2d,
@@ -204,4 +198,4 @@ class SimulatorImaging(imaging.SimulatorImaging):
             map(lambda g: g.profile_image_from_grid(grid=deflected_grid), galaxies)
         )
 
-        return self.from_image(image=image, name=name, metadata=metadata)
+        return self.from_image(image=image, name=name)
