@@ -14,9 +14,14 @@ If on super computer:
 @numba.jit(nopython=True, cache=False, parallel=True)
 """
 
-nopython = af.conf.instance.general.get("numba", "nopython", bool)
-cache = af.conf.instance.general.get("numba", "cache", bool)
-parallel = af.conf.instance.general.get("numba", "parallel", bool)
+try:
+    nopython = af.conf.instance.general.get("numba", "nopython", bool)
+    cache = af.conf.instance.general.get("numba", "cache", bool)
+    parallel = af.conf.instance.general.get("numba", "parallel", bool)
+except Exception:
+    nopython = True
+    cache = True
+    parallel = False
 
 
 def jit(nopython=nopython, cache=cache, parallel=parallel):
@@ -24,4 +29,3 @@ def jit(nopython=nopython, cache=cache, parallel=parallel):
         return numba.jit(func, nopython=nopython, cache=cache, parallel=parallel)
 
     return wrapper
-
