@@ -5,7 +5,7 @@ from autolens.lens import ray_tracing
 
 def last_result_with_use_as_hyper_dataset(results):
 
-    if results is not None:
+    if results.last is not None:
         for index, result in enumerate(reversed(results)):
             if result.use_as_hyper_dataset:
                 return result
@@ -72,11 +72,13 @@ class Analysis(af.Analysis):
            The input instance with images associated with galaxies where possible.
         """
         if self.hyper_galaxy_image_path_dict is not None:
+
             for galaxy_path, galaxy in instance.path_instance_tuples_for_class(
                 g.Galaxy
             ):
                 if galaxy_path in self.hyper_galaxy_image_path_dict:
                     galaxy.hyper_model_image = self.hyper_model_image
+
                     galaxy.hyper_galaxy_image = self.hyper_galaxy_image_path_dict[
                         galaxy_path
                     ]
