@@ -39,7 +39,14 @@ class PhaseDataset(abstract.AbstractPhase):
 
         self.is_hyper_phase = False
 
-    def run(self, dataset: Dataset, mask, results=None, positions=None):
+    def run(
+        self,
+        dataset: Dataset,
+        mask,
+        results=af.ResultsCollection(),
+        positions=None,
+        info=None,
+    ):
         """
         Run this phase.
 
@@ -58,10 +65,11 @@ class PhaseDataset(abstract.AbstractPhase):
         result: AbstractPhase.Result
             A result object comprising the best fit model and other hyper_galaxies.
         """
-        dataset.save(self.paths.phase_output_path)
-        self.save_metadata(dataset)
+        self.save_metadata(dataset=dataset)
+        self.save_dataset(dataset=dataset)
         self.save_mask(mask)
         self.save_meta_dataset(meta_dataset=self.meta_dataset)
+        self.save_info(info=info)
 
         self.model = self.model.populate(results)
 
@@ -79,7 +87,9 @@ class PhaseDataset(abstract.AbstractPhase):
 
         return self.make_result(result=result, analysis=analysis)
 
-    def make_analysis(self, dataset, mask, results=None, positions=None):
+    def make_analysis(
+        self, dataset, mask, results=af.ResultsCollection(), positions=None
+    ):
         """
         Create an lens object. Also calls the prior passing and masked_imaging modifying functions to allow child
         classes to change the behaviour of the phase.
