@@ -38,6 +38,7 @@ class CombinedHyperPhase(HyperPhase):
         mask,
         results: af.ResultsCollection = None,
         positions=None,
+        info=None,
         **kwargs
     ) -> af.Result:
         """
@@ -63,12 +64,19 @@ class CombinedHyperPhase(HyperPhase):
         """
         results = results.copy() if results is not None else af.ResultsCollection()
         result = self.phase.run(
-            dataset=dataset, mask=mask, results=results, positions=positions, **kwargs
+            dataset=dataset,
+            mask=mask,
+            results=results,
+            positions=positions,
+            info=info,
+            **kwargs
         )
         results.add(self.phase.paths.phase_name, result)
 
         for phase in self.hyper_phases:
-            hyper_result = phase.run_hyper(dataset=dataset, results=results, **kwargs)
+            hyper_result = phase.run_hyper(
+                dataset=dataset, results=results, info=info, **kwargs
+            )
             setattr(result, phase.hyper_name, hyper_result)
 
         setattr(
@@ -98,7 +106,7 @@ class CombinedHyperPhase(HyperPhase):
             model += getattr(result, name).model
         return model
 
-    def run_hyper(self, dataset, results, **kwargs) -> af.Result:
+    def run_hyper(self, dataset, results, info=None, **kwargs) -> af.Result:
 
         phase = self.make_hyper_phase()
         phase.model = self.combine_models(results.last)
@@ -108,4 +116,5 @@ class CombinedHyperPhase(HyperPhase):
             mask=results.last.mask,
             results=results,
             positions=results.last.positions,
+            info=info,
         )
