@@ -10,6 +10,7 @@ class MetaInterferometer(meta_dataset.MetaDataset):
         transformer_class,
         sub_size=2,
         is_hyper_phase=False,
+        auto_positions_factor=None,
         positions_threshold=None,
         pixel_scale_interpolation_grid=None,
         inversion_uses_border=True,
@@ -21,6 +22,7 @@ class MetaInterferometer(meta_dataset.MetaDataset):
             model=model,
             sub_size=sub_size,
             is_hyper_phase=is_hyper_phase,
+            auto_positions_factor=auto_positions_factor,
             positions_threshold=positions_threshold,
             pixel_scale_interpolation_grid=pixel_scale_interpolation_grid,
             inversion_uses_border=inversion_uses_border,
@@ -39,6 +41,10 @@ class MetaInterferometer(meta_dataset.MetaDataset):
             mask=self.real_space_mask
         )
 
+        positions = self.updated_positions_from_positions_and_results(
+            positions=positions, results=results
+        )
+
         self.check_positions(positions=positions)
 
         preload_sparse_grids_of_planes = self.preload_pixelization_grids_of_planes_from_results(
