@@ -79,7 +79,7 @@ class Result(dataset.Result):
     @property
     def hyper_model_visibilities(self):
 
-        hyper_model_visibilities = aa.visibilities.zeros(
+        hyper_model_visibilities = aa.Visibilities.zeros(
             shape_1d=(self.most_likely_fit.visibilities.shape_1d,)
         )
 
@@ -139,7 +139,7 @@ class Result(dataset.Result):
     @property
     def hyper_model_image(self):
 
-        hyper_model_image = aa.masked_array.zeros(mask=self.real_space_mask.mask_sub_1)
+        hyper_model_image = aa.MaskedArray.zeros(mask=self.real_space_mask.mask_sub_1)
 
         for path, galaxy in self.path_galaxy_tuples:
             hyper_model_image += self.hyper_galaxy_image_path_dict[path]
