@@ -2,10 +2,14 @@ import autofit as af
 
 
 class PipelineDataset(af.Pipeline):
-    def run(self, dataset, mask, positions=None):
+    def run(self, dataset, mask, positions=None, info=None):
         def runner(phase, results):
             return phase.run(
-                dataset=dataset, results=results, mask=mask, positions=positions
+                dataset=dataset,
+                results=results,
+                mask=mask,
+                positions=positions,
+                info=info,
             )
 
         return self.run_function(runner)
