@@ -9,8 +9,8 @@ from test import simulate_util
 imaging = simulate_util.load_test_imaging(
     data_type="lens_light_dev_vaucouleurs", data_resolution="lsst"
 )
-mask = al.mask.circular(
-    shape_2d=imaging.shape, pixel_scales=imaging.pixel_scales, radius=3.0
+mask = al.Mask.circular(
+    shape_2d=imaging.shape_2d, pixel_scales=imaging.pixel_scales, radius=3.0
 )
 
 # The lines of code below do everything we're used to, that is, setup an image and its grid, mask it, trace it
@@ -21,8 +21,8 @@ lens_galaxy = al.Galaxy(
     )
 )
 
-masked_imaging = al.masked_imaging(imaging=imaging, mask=mask)
+masked_imaging = al.MaskedImaging(imaging=imaging, mask=mask)
 
 tracer = al.Tracer.from_galaxies(galaxies=[lens_galaxy])
-fit = al.fit(masked_dataset=masked_imaging, tracer=tracer)
+fit = al.FitImaging(masked_imaging=masked_imaging, tracer=tracer)
 aplt_array.fit_imaging.subplot_imaging(fit=fit, mask=True)
